@@ -40,8 +40,8 @@ use File::Copy;
 use File::Basename;
 use Cwd;
 use Dpkg::Vendor qw(get_current_vendor);
-use Dpkg::Changelog::Parse;
-BEGIN { push @INC, '/usr/share/devscripts'; }
+use Dpkg::Changelog::Parse qw(changelog_parse);
+use Dpkg::Control;
 use Devscripts::Compression;
 use Devscripts::Debbugs;
 use POSIX qw(locale_h strftime);
@@ -60,25 +60,6 @@ my $CHGLINE;  # used by the format O section at the end
 
 my $compression_re = compression_get_file_extension_regex();
 
-my $lpdc_broken;
-
-sub have_lpdc {
-    return ($lpdc_broken ? 0 : 1) if defined $lpdc_broken;
-    eval {
-	require Parse::DebControl;
-    };
-
-    if ($@) {
-	if ($@ =~ m%^Can\'t locate Parse/DebControl%) {
-	    $lpdc_broken="the libparse-debcontrol-perl package is not installed";
-	} else {
-	    $lpdc_broken="couldn't load Parse::DebControl: $@";
-	}
-    }
-    else { $lpdc_broken=''; }
-    return $lpdc_broken ? 0 : 1;
-}
-
 my $debian_distro_info;
 sub get_debian_distro_info {
     return $debian_distro_info if defined $debian_distro_info;
@@ -179,7 +160,7 @@ Options:
          distribution name
   --bpo
          Increment the Debian release number for a backports upload
-         to "wheezy-backports"
+         to "jessie-backports"
   -l, --local <suffix>
          Add a suffix to the Debian version number for a local build
   -b, --force-bad-version
@@ -624,15 +605,15 @@ my $MAINTAINER = 'MAINTAINER';
 my $EMAIL = 'EMAIL';
 my $DISTRIBUTION = 'UNRELEASED';
 my $bpo_dist = '';
-my %bpo_dists = ( 60, 'squeeze', 70, 'wheezy', 80, 'jessie' );
-my $latest_bpo_dist = '70';
+my %bpo_dists = ( 60, 'squeeze', 70, 'wheezy', 8, 'jessie' );
+my $latest_bpo_dist = '8';
 my $CHANGES = '';
 # Changelog urgency, possibly propogated to NEWS files
 my $CL_URGENCY = '';
 
 if (! $opt_create || ($opt_create && $opt_news)) {
     my $file = $opt_create ? 'debian/changelog' : $changelog_path;
-    $changelog = Dpkg::Changelog::Parse::changelog_parse(file => $file);
+    $changelog = changelog_parse(file => $file);
 
     # Now we've read the changelog, set some variables and then
     # let's check the directory name is sensible
@@ -663,7 +644,7 @@ if (! $opt_create || ($opt_create && $opt_news)) {
     if ($opt_news) {
 	my $found_version = 0;
 	my $found_urgency = 0;
-	my $clog = Dpkg::Changelog::Parse::changelog_parse(file => $real_changelog_path);
+	my $clog = changelog_parse(file => $real_changelog_path);
 	$VERSION = $clog->{Version};
 	$VERSION =~ s/~$//;
 
@@ -814,18 +795,14 @@ if (! $opt_m and ! $opt_M) {
 
 if ($opt_M) {
     if (-f 'debian/control') {
-	if (have_lpdc()) {
-	    my $parser = Parse::DebControl->new;
-	    my $deb822 = $parser->parse_file('debian/control', {stripComments => 'true'});
-	    my $maintainer = decode_utf8($deb822->[0]->{'Maintainer'});
-	    if ($maintainer =~ /^(.*)\s+<(.*)>$/) {
-		$MAINTAINER = $1;
-		$EMAIL = $2;
-	    } else {
-		fatal "$progname: invalid debian/control Maintainer field value\n";
-	    }
+	my $parser = Dpkg::Control->new(type => CTRL_INFO_SRC);
+	$parser->load('debian/control');
+	my $maintainer = decode_utf8($parser->{Maintainer});
+	if ($maintainer =~ /^(.*)\s+<(.*)>$/) {
+	    $MAINTAINER = $1;
+	    $EMAIL = $2;
 	} else {
-	    fatal "$progname: unable to get maintainer from debian/control: $lpdc_broken\n";
+	    fatal "$progname: invalid debian/control Maintainer field value\n";
 	}
     } else {
 	fatal "Missing file debian/control";
@@ -844,23 +821,19 @@ if ($opt_auto_nmu eq 'yes' and ! $opt_v and ! $opt_l and ! $opt_s and
        $changelog->{Distribution} eq 'UNRELEASED' and ! $opt_i_passed)) {
 
     if (-f 'debian/control') {
-	if (have_lpdc()) {
-	    my $parser = new Parse::DebControl;
-	    my $deb822 = $parser->parse_file('debian/control', {stripComments => 'true'});
-	    my $uploader = decode_utf8($deb822->[0]->{'Uploaders'}) || '';
-	    my $maintainer = decode_utf8($deb822->[0]->{'Maintainer'});
-	    my @uploaders = split(/,\s*/, $uploader);
+	my $parser = Dpkg::Control->new(type => CTRL_INFO_SRC);
+	$parser->load('debian/control');
+	my $uploader = decode_utf8($parser->{Uploaders}) || '';
+	my $maintainer = decode_utf8($parser->{Maintainer});
+	my @uploaders = split(/,\s*/, $uploader);
 
-	    my $packager = "$MAINTAINER <$EMAIL>";
+	my $packager = "$MAINTAINER <$EMAIL>";
 
-	    if ($maintainer !~ m/<packages\@qa\.debian\.org>/ and
-		! grep { $_ eq $packager } ($maintainer, @uploaders) and
-		$packager ne $changelog->{Maintainer} and ! $opt_team) {
-		$opt_n=1;
-		$opt_a=0;
-	    }
-	} else {
-	    warn "$progname: skipping automatic NMU detection: $lpdc_broken\n";
+	if ($maintainer !~ m/<packages\@qa\.debian\.org>/ and
+	    ! grep { $_ eq $packager } ($maintainer, @uploaders) and
+	    $packager ne $changelog->{Maintainer} and ! $opt_team) {
+	    $opt_n=1;
+	    $opt_a=0;
 	}
     } else {
 	fatal "Missing file debian/control";
@@ -1582,16 +1555,11 @@ if ((basename(cwd()) =~ m%^\Q$PACKAGE\E-\Q$UVERSION\E$%) &&
     !$opt_p && !$opt_create) {
     # Find the current version number etc.
     my ($new_version, $new_sversion, $new_uversion);
-    open PARSED, "dpkg-parsechangelog |"
-	or fatal "Cannot execute dpkg-parsechangelog: $!";
-    while (<PARSED>) {
-	if (/^Version:\s(.+?)\s*$/) { $new_version=$1; }
+    my $changelog = changelog_parse();
+    if (exists $changelog->{Version}) {
+	$new_version = $changelog->{Version};
     }
 
-    close PARSED
-	or fatal "Problem executing dpkg-parsechangelog: $!";
-    if ($?) { fatal "dpkg-parsechangelog failed!" }
-
     fatal "No version number in debian/changelog!"
 	unless defined $new_version;
 
